This follows the palette-function pattern used by scientific palette packages: the returned function accepts the number of colours needed.
Usage
pal_ggpalette(
name = "meadow",
alpha = 1,
reverse = FALSE,
space = c("Lab", "rgb")
)This follows the palette-function pattern used by scientific palette packages: the returned function accepts the number of colours needed.
pal_ggpalette(
name = "meadow",
alpha = 1,
reverse = FALSE,
space = c("Lab", "rgb")
)